==> estateplat-common-1.2.3-20180710.104808-145-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfCsgp.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/11/2
 * @description 存量房出售挂牌属性结构描述表
 */
@Table(name = "fcjy_clf_csgp")
public class FcjyClfCsgp implements InsertVo {
    @Id
    private String csgpid;//主键
    private Long csgpbh;//出售挂牌编号
    private String gplx;//挂牌类型
    private String gplb;//挂牌类别
    private String hbh;//户编号
    private String qxh;//区县号
    private String slcbh;//受理处编号
    private String jyybh;//交易员编号
    private String gpbz;//挂牌币种
    private Double gpjg;//挂牌价格
    private String fbzl;//发布坐落
    private String xqmc;//小区名称
    private String hx;//户型
    private Double rjl;//容积率
    private String fxt;//房型图
    private String jgt;//景观图
    private String lc;//楼层
    private String cx;//朝向
    private String zxcd;//装修程度
    private String fwzscl;//房屋装饰处理
    private String wxzjjsfs;//维修资金结算方式
    private String mjgc;//面积构成
    private String ptss;//配套设施
    private String jtxl;//交通线路
    private String dlfw;//地理方位
    private String wygs;//物业公司
    private Double wyglf;//物业管理费
    private Date jfrq;//交房日期
    private String dzyzk;//带租约状况
    private Double jzmj;//建筑面积
    private Double ftmj;//分摊面积
    private String fwjg;//房屋结构
    private String fwlx;//房屋类型
    private String szc;//所在层
    private String zcs;//总层数
    private String cqzh;//产权证号
    private Double symj;//使用面积
    private String ghyt;//规划用途
    private String jcnf;//建成年份
    private String qlr;//权利人
    private String qlrzjhm;//权利人证件号码
    private String qlrzz;//权利人住址
    private String qlrlxdh;//权利人联系电话
    private Integer gpqx;//挂牌期限（天）
    private Date gpqsrq;//挂牌起始日期
    private Date gpjzrq;//挂牌截止日期
    private String gpzt;//挂牌状态
    private String cxr;//撤销人
    private Date cxsj;//撤销时间
    private String cxyy;//撤销原因
    private String shr;//审核人
    private Date shsj;//审核时间
    private String shyj;//审核意见
    private String xmly;//项目来源
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String bz;//备注
    private String fwxz;//房屋性质
    private String yfwxz;//原房屋性质
    private Double mmgpjg;//买卖挂牌价格
    private Double zlgpjg;//租赁挂牌价格
    private String sfys; //是否可售

    public String getCsgpid() {
        return csgpid;
    }

    public void setCsgpid(String csgpid) {
        this.csgpid = csgpid;
    }

    public Long getCsgpbh() {
        return csgpbh;
    }

    public void setCsgpbh(Long csgpbh) {
        this.csgpbh = csgpbh;
    }

    public String getGplx() {
        return gplx;
    }

    public void setGplx(String gplx) {
        this.gplx = gplx;
    }

    public String getGplb() {
        return gplb;
    }

    public void setGplb(String gplb) {
        this.gplb = gplb;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getSlcbh() {
        return slcbh;
    }

    public void setSlcbh(String slcbh) {
        this.slcbh = slcbh;
    }

    public String getJyybh() {
        return jyybh;
    }

    public void setJyybh(String jyybh) {
        this.jyybh = jyybh;
    }

    public String getGpbz() {
        return gpbz;
    }

    public void setGpbz(String gpbz) {
        this.gpbz = gpbz;
    }

    public Double getGpjg() {
        return gpjg;
    }

    public void setGpjg(Double gpjg) {
        this.gpjg = gpjg;
    }

    public String getFbzl() {
        return fbzl;
    }

    public void setFbzl(String fbzl) {
        this.fbzl = fbzl;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public String getFxt() {
        return fxt;
    }

    public void setFxt(String fxt) {
        this.fxt = fxt;
    }

    public String getJgt() {
        return jgt;
    }

    public void setJgt(String jgt) {
        this.jgt = jgt;
    }

    public String getLc() {
        return lc;
    }

    public void setLc(String lc) {
        this.lc = lc;
    }

    public String getCx() {
        return cx;
    }

    public void setCx(String cx) {
        this.cx = cx;
    }

    public String getZxcd() {
        return zxcd;
    }

    public void setZxcd(String zxcd) {
        this.zxcd = zxcd;
    }

    public String getFwzscl() {
        return fwzscl;
    }

    public void setFwzscl(String fwzscl) {
        this.fwzscl = fwzscl;
    }

    public String getWxzjjsfs() {
        return wxzjjsfs;
    }

    public void setWxzjjsfs(String wxzjjsfs) {
        this.wxzjjsfs = wxzjjsfs;
    }

    public String getMjgc() {
        return mjgc;
    }

    public void setMjgc(String mjgc) {
        this.mjgc = mjgc;
    }

    public String getPtss() {
        return ptss;
    }

    public void setPtss(String ptss) {
        this.ptss = ptss;
    }

    public String getJtxl() {
        return jtxl;
    }

    public void setJtxl(String jtxl) {
        this.jtxl = jtxl;
    }

    public String getDlfw() {
        return dlfw;
    }

    public void setDlfw(String dlfw) {
        this.dlfw = dlfw;
    }

    public String getWygs() {
        return wygs;
    }

    public void setWygs(String wygs) {
        this.wygs = wygs;
    }

    public Double getWyglf() {
        return wyglf;
    }

    public void setWyglf(Double wyglf) {
        this.wyglf = wyglf;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getDzyzk() {
        return dzyzk;
    }

    public void setDzyzk(String dzyzk) {
        this.dzyzk = dzyzk;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjhm() {
        return qlrzjhm;
    }

    public void setQlrzjhm(String qlrzjhm) {
        this.qlrzjhm = qlrzjhm;
    }

    public String getQlrzz() {
        return qlrzz;
    }

    public void setQlrzz(String qlrzz) {
        this.qlrzz = qlrzz;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public Integer getGpqx() {
        return gpqx;
    }

    public void setGpqx(Integer gpqx) {
        this.gpqx = gpqx;
    }

    public Date getGpqsrq() {
        return gpqsrq;
    }

    public void setGpqsrq(Date gpqsrq) {
        this.gpqsrq = gpqsrq;
    }

    public Date getGpjzrq() {
        return gpjzrq;
    }

    public void setGpjzrq(Date gpjzrq) {
        this.gpjzrq = gpjzrq;
    }

    public String getGpzt() {
        return gpzt;
    }

    public void setGpzt(String gpzt) {
        this.gpzt = gpzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public String getCxr() {
        return cxr;
    }

    public void setCxr(String cxr) {
        this.cxr = cxr;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getCxyy() {
        return cxyy;
    }

    public void setCxyy(String cxyy) {
        this.cxyy = cxyy;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShsj() {
        return shsj;
    }

    public void setShsj(Date shsj) {
        this.shsj = shsj;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }

    public Double getMmgpjg() {
        return mmgpjg;
    }

    public void setMmgpjg(Double mmgpjg) {
        this.mmgpjg = mmgpjg;
    }

    public Double getZlgpjg() {
        return zlgpjg;
    }

    public void setZlgpjg(Double zlgpjg) {
        this.zlgpjg = zlgpjg;
    }

    public String getSfys() { return sfys; }

    public void setSfys(String sfys) { this.sfys = sfys; }
}

==> estateplat-common-1.2.4-20191231.052851-238-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfCsgp.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/11/2
 * @description 存量房出售挂牌属性结构描述表
 */
@Table(name = "fcjy_clf_csgp")
public class FcjyClfCsgp implements InsertVo {
    @Id
    private String csgpid;//主键
    private Long csgpbh;//出售挂牌编号
    private String gplx;//挂牌类型
    private String gplb;//挂牌类别
    private String hbh;//户编号
    private String qxh;//区县号
    private String slcbh;//受理处编号
    private String jyybh;//交易员编号
    private String gpbz;//挂牌币种
    private Double gpjg;//挂牌价格
    private String fbzl;//发布坐落
    private String xqmc;//小区名称
    private String hx;//户型
    private Double rjl;//容积率
    private String fxt;//房型图
    private String jgt;//景观图
    private String lc;//楼层
    private String cx;//朝向
    private String zxcd;//装修程度
    private String fwzscl;//房屋装饰处理
    private String wxzjjsfs;//维修资金结算方式
    private String mjgc;//面积构成
    private String ptss;//配套设施
    private String jtxl;//交通线路
    private String dlfw;//地理方位
    private String wygs;//物业公司
    private Double wyglf;//物业管理费
    private Date jfrq;//交房日期
    private String dzyzk;//带租约状况
    private Double jzmj;//建筑面积
    private Double ftmj;//分摊面积
    private String fwjg;//房屋结构
    private String fwlx;//房屋类型
    private String szc;//所在层
    private String zcs;//总层数
    private String cqzh;//产权证号
    private Double symj;//使用面积
    private String ghyt;//规划用途
    private String jcnf;//建成年份
    private String qlr;//权利人
    private String qlrzjhm;//权利人证件号码
    private String qlrzz;//权利人住址
    private String qlrlxdh;//权利人联系电话
    private Integer gpqx;//挂牌期限（天）
    private Date gpqsrq;//挂牌起始日期
    private Date gpjzrq;//挂牌截止日期
    private String gpzt;//挂牌状态
    private String cxr;//撤销人
    private Date cxsj;//撤销时间
    private String cxyy;//撤销原因
    private String shr;//审核人
    private Date shsj;//审核时间
    private String shyj;//审核意见
    private String xmly;//项目来源
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String bz;//备注
    private String fwxz;//房屋性质
    private String yfwxz;//原房屋性质
    private Double mmgpjg;//买卖挂牌价格
    private Double zlgpjg;//租赁挂牌价格
    private String sfys; //是否可售

    private Long jjhtbh;//经纪合同编号
    private String wtjglxfs;//委托机构联系方式

    public Long getJjhtbh() {
        return jjhtbh;
    }

    public void setJjhtbh(Long jjhtbh) {
        this.jjhtbh = jjhtbh;
    }

    public String getWtjglxfs() {
        return wtjglxfs;
    }

    public void setWtjglxfs(String wtjglxfs) {
        this.wtjglxfs = wtjglxfs;
    }

    public String getCsgpid() {
        return csgpid;
    }

    public void setCsgpid(String csgpid) {
        this.csgpid = csgpid;
    }

    public Long getCsgpbh() {
        return csgpbh;
    }

    public void setCsgpbh(Long csgpbh) {
        this.csgpbh = csgpbh;
    }

    public String getGplx() {
        return gplx;
    }

    public void setGplx(String gplx) {
        this.gplx = gplx;
    }

    public String getGplb() {
        return gplb;
    }

    public void setGplb(String gplb) {
        this.gplb = gplb;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getSlcbh() {
        return slcbh;
    }

    public void setSlcbh(String slcbh) {
        this.slcbh = slcbh;
    }

    public String getJyybh() {
        return jyybh;
    }

    public void setJyybh(String jyybh) {
        this.jyybh = jyybh;
    }

    public String getGpbz() {
        return gpbz;
    }

    public void setGpbz(String gpbz) {
        this.gpbz = gpbz;
    }

    public Double getGpjg() {
        return gpjg;
    }

    public void setGpjg(Double gpjg) {
        this.gpjg = gpjg;
    }

    public String getFbzl() {
        return fbzl;
    }

    public void setFbzl(String fbzl) {
        this.fbzl = fbzl;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public Double getRjl() {
        return rjl;
    }

    public void setRjl(Double rjl) {
        this.rjl = rjl;
    }

    public String getFxt() {
        return fxt;
    }

    public void setFxt(String fxt) {
        this.fxt = fxt;
    }

    public String getJgt() {
        return jgt;
    }

    public void setJgt(String jgt) {
        this.jgt = jgt;
    }

    public String getLc() {
        return lc;
    }

    public void setLc(String lc) {
        this.lc = lc;
    }

    public String getCx() {
        return cx;
    }

    public void setCx(String cx) {
        this.cx = cx;
    }

    public String getZxcd() {
        return zxcd;
    }

    public void setZxcd(String zxcd) {
        this.zxcd = zxcd;
    }

    public String getFwzscl() {
        return fwzscl;
    }

    public void setFwzscl(String fwzscl) {
        this.fwzscl = fwzscl;
    }

    public String getWxzjjsfs() {
        return wxzjjsfs;
    }

    public void setWxzjjsfs(String wxzjjsfs) {
        this.wxzjjsfs = wxzjjsfs;
    }

    public String getMjgc() {
        return mjgc;
    }

    public void setMjgc(String mjgc) {
        this.mjgc = mjgc;
    }

    public String getPtss() {
        return ptss;
    }

    public void setPtss(String ptss) {
        this.ptss = ptss;
    }

    public String getJtxl() {
        return jtxl;
    }

    public void setJtxl(String jtxl) {
        this.jtxl = jtxl;
    }

    public String getDlfw() {
        return dlfw;
    }

    public void setDlfw(String dlfw) {
        this.dlfw = dlfw;
    }

    public String getWygs() {
        return wygs;
    }

    public void setWygs(String wygs) {
        this.wygs = wygs;
    }

    public Double getWyglf() {
        return wyglf;
    }

    public void setWyglf(Double wyglf) {
        this.wyglf = wyglf;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getDzyzk() {
        return dzyzk;
    }

    public void setDzyzk(String dzyzk) {
        this.dzyzk = dzyzk;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjhm() {
        return qlrzjhm;
    }

    public void setQlrzjhm(String qlrzjhm) {
        this.qlrzjhm = qlrzjhm;
    }

    public String getQlrzz() {
        return qlrzz;
    }

    public void setQlrzz(String qlrzz) {
        this.qlrzz = qlrzz;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public Integer getGpqx() {
        return gpqx;
    }

    public void setGpqx(Integer gpqx) {
        this.gpqx = gpqx;
    }

    public Date getGpqsrq() {
        return gpqsrq;
    }

    public void setGpqsrq(Date gpqsrq) {
        this.gpqsrq = gpqsrq;
    }

    public Date getGpjzrq() {
        return gpjzrq;
    }

    public void setGpjzrq(Date gpjzrq) {
        this.gpjzrq = gpjzrq;
    }

    public String getGpzt() {
        return gpzt;
    }

    public void setGpzt(String gpzt) {
        this.gpzt = gpzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public String getCxr() {
        return cxr;
    }

    public void setCxr(String cxr) {
        this.cxr = cxr;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getCxyy() {
        return cxyy;
    }

    public void setCxyy(String cxyy) {
        this.cxyy = cxyy;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShsj() {
        return shsj;
    }

    public void setShsj(Date shsj) {
        this.shsj = shsj;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }

    public Double getMmgpjg() {
        return mmgpjg;
    }

    public void setMmgpjg(Double mmgpjg) {
        this.mmgpjg = mmgpjg;
    }

    public Double getZlgpjg() {
        return zlgpjg;
    }

    public void setZlgpjg(Double zlgpjg) {
        this.zlgpjg = zlgpjg;
    }

    public String getSfys() { return sfys; }

    public void setSfys(String sfys) { this.sfys = sfys; }
}
